generate_sector_circuit_description

Function generate_sector_circuit_description 

pub fn generate_sector_circuit_description<F: Field>(
    sectors: &[&Sector<F>],
    circuit_map: &mut CircuitMap,
    maybe_maximum_log_layer_size: Option<usize>,
) -> Vec<LayerDescriptionEnum<F>>
Generate a circuit description for a vector of sectors that are to be combined. I.e., the sectors passed into this function do not have any dependencies between each other. The expected behavior of this function is to return a single layer which has merged the expressions of each of the individual sectors into a single expression.